@@ -1,7 +1,7 @@
 #!/usr/local/bin/python2.7
 # -*- coding: utf-8 -*-
 #
-# (c) Copyright 2003-2008 Hewlett-Packard Development Company, L.P.
+# (c) Copyright 2003-2015 HP Development Company, L.P.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -101,11 +101,13 @@ TECH_CLASSES = [
     "Pyramid15",
     "Python10",
     "Mimas",
+    "Mimas15",
     "StingrayOJ",
     "Copperhead",
     "CopperheadXLP",
     "Copperhead12",
     "CopperheadIPH",
+    "CopperheadIPH15",
     "PyramidRefresh15",
     "Ampere",
     "Python11",
@@ -167,12 +169,14 @@ TECH_CLASS_PDLS = {
     "OJ7000"        : 'pcl3',
     "Python10"      : 'pcl3',
     "Mimas"      : 'pcl3',
+    "Mimas15"      : 'pcl3',
     "StingrayOJ"   : 'pcl3',
     "Pyramid15"   : 'pcl3',
     "Copperhead"   : 'pcl3',
     "CopperheadXLP"   : 'pcl3',
     "Copperhead12"   : 'pcl3',
     "CopperheadIPH"   : 'pcl3',
+    "CopperheadIPH15"   : 'pcl3',
     "PyramidRefresh15": 'pcl3',
     "Ampere"        : 'pcl3',
     "Hbpl1"         : 'hbpl1',
